@@ -76,10 +76,6 @@ class ServiceAlreadyExists(OctueSDKException):
     """Raise if trying to create a service with the ID of an existing service."""
 
 
-class QuestionNotDelivered(OctueSDKException):
-    """Raise if a question has not been delivered or no acknowledgement of its delivery has been received."""
-
-
 class BackendNotFound(OctueSDKException):
     """Raise when details of a backend that doesn't exist in `octue.resources.service_backends` are given for use as a
     Service backend.
